@@ -279,7 +279,7 @@
            x_axis_label,
            y_axis_label) {
     
-    
+
     # Global variables -------------------------------------------------------
     
     # Colors PPV
@@ -320,6 +320,8 @@
       
       # [TODO] Can USE PPV_melted to get this?
       breaks_x = round(seq(from = Min_FP, to = Max_FP, by = Step_size_FP * 10), decimals_x)
+      # With no decimals sometimes the breaks are not equidistant. This is a hacky way to solve it
+      if (length(unique(diff(breaks_x))) > 1) breaks_x = round(seq(from = Min_FP, to = Max_FP, by = Step_size_FP * 10), decimals_x + 1)
       labels_x = paste0(breaks_x, "%")
       
       breaks_y = round(unique(PPV_melted$Prevalence)[c(seq(1, steps_matrix, 10), 101)], decimals_y)
@@ -597,7 +599,7 @@
   # Size of geom_mark_rect()
   if (uncertainty_prevalence == "high") {
     uncertainty_prevalence_num = .02
-  } else if (uncertainty_prevalence == "low"){
+  } else if (uncertainty_prevalence == "low") {
     uncertainty_prevalence_num = .01
   }  
     
@@ -661,7 +663,7 @@
                                x = x_axis_position,
                                y = overlay_prevalence_2,
                                group = overlay_labels,
-                               description = overlay_labels),
+                               label = overlay_labels),
                              fill = "red", 
                              # con.border = "none", 
                              con.size = .2)
